// Triang1.cpp (C) 2005 adolfo@di-mare.com

/** \file  Triang1.cpp
    \brief Ejemplo de una funcin que determina el tipo de tringulo.

     Forma de uso:
     C:\DIR\SubDir> TriangV1 10 12 10

    \author Adolfo Di Mare <adolfo@di-mare.com>
    \date   2006
*/

#include <stdio.h>  // printf()
#include <stdlib.h> // atoi()
#include <string.h> // strcmp()

/// Determina si los valores de \c argv[] son los lados de un tringulo.
/// - Retorna una hilera que indica el tipo de tringulo:
///   - "EQL" ==> Equilteros
///   - "ISO" ==> Issceles
///   - "ESC" ==> Escalen
const char* Triangulador(int argc, char *argv[]) {
    int a,b,c; // lados del tringulo

    a = atoi( argv[1] ); // atoi() convierte hileras en enteros
    b = atoi( argv[2] );
    c = atoi( argv[3] );

    if ( a==b && b==c && a==c ) {
        return "EQL";
    } else if ( a==b || b==c || a==c ) {
        return "ISO";
    } else {
        return "ESC";
    }
} // Triangulador()

/// Emite el error en bonito.
void Error (int argc, char *argv[]) {
    printf("Error[%s] ==>", argv[0]);

    for (int i = 1; i < argc; ++i) {
        printf(" [%s]", argv[i]);
    }
    printf("\n");
} // Error ()

/// DIM() no se puede implementar con plantillas...
#define DIM(V) (sizeof(V) / sizeof(*V)) // *V == *(V+0) == V[0]

/// Programa principal.
int main (int argc, char *argv[]) {

    char* T1[] = { "ISO", "8", "10", "8" };
    if ( Triangulador(DIM(T1), T1) != T1[0] ) { Error( DIM(T1), T1 ); }

    return 0;

} // main()

/*  T1[]
    +---+
    |   |   +---+---+---+---+
    | *-|-->|'I'|'S'|'O'|0x0|
    |   |   +---+---+---+---+
    +---+
    |   |   +---+---+
    | *-|-->|'8'|0x0|
    |   |   +---+---+
    +---+
    |   |   +---+---+---+
    | *-|-->|'1'|'0'|0x0|
    |   |   +---+---+---+
    +---+
    |   |   +---+---+
    | *-|-->|'8'|0x0|
    |   |   +---+---+
    +---+
*/

/*  T1[]
    +---+   +---+---+---+---+
    | *-|-->|'I'|'S'|'O'|0x0|
    |   |   +---+---+---+---+
    +---+   +---+---+
    | *-|-->|'8'|0x0|
    |   |   +---+---+
    +---+   +---+---+---+
    | *-|-->|'1'|'0'|0x0|
    |   |   +---+---+---+
    +---+   +---+---+
    | *-|-->|'8'|0x0|
    |   |   +---+---+
    +---+
*/

/*

> Profe: > Me hice un mdulo para los casos de prueba, pero a la hora de
> comparar me da que no lo encuentra. Qu hago? Ya prob con el Borland
> y el error sigue. 

No me ests hablando de casos de prueba, sino ms bien de datos de prueba. 

Tu problema es que Triangulador() retorna un puntero a una hilera local,
el que luego compars con la hilera que est en T1[]:
    if ( Triangulador(DIM(T1), T1) != T1[0] ) { Error( DIM(T1), T1); }

Esta comparacin es una comparacin de PUNTEROS, que apuntan a lugares de
memoria diferente, por lo que el resultado es FALSO. Para comprar las hileras
hay que usar una funcin que lo haga, como es el caso de memcmp() o de strcmp():

    const char* res = Triangulador( DIM(T1), T1 );
    if ( 0 != strcmp(res, T1[0]) ) { Error( DIM(T1), T1 ); }

Si sustitus tu if() por ste otro, vers que el programa funciona
correctamente.

        Adolfo
               ///
*/

// EOF: Triang1.cpp