// test_Triangulo.cpp (C) 2007 adolfo@di-mare.com

/** \file  test_Triangulo.cpp
    \brief Mdulo de prueba para el programa del tringulo de Myers.

    Este cdigo est basado en el trabajo libro de texto:
    Myers, Glenford: "The Art of Software Testing"; John Wiley & Sons; pp 2; 1978.

    \author Adolfo Di Mare <adolfo@di-mare.com>
    \date   2007
*/

enum TRIANGULO { NO_TRIANGULO=0, EQUILATERO, ISOSCELES, ESCALENO };

/** Retorna una cdigo numrico que indica si el tringulo es:
    - EQUILATERO   ==> Equiltero
    - ISOSCELES    ==> Issceles
    - ESCALENO     ==> Escaleno
    - NO_TRIANGULO ==> No es tringulo
*/
int Tipo_Triangulo( int A, int B, int C ) {

    bool es_triangulo = true;

    es_triangulo = es_triangulo && ( A > 0 ); // Los lados deben ser
    es_triangulo = es_triangulo && ( B > 0 ); // un nmero positivo
    es_triangulo = es_triangulo && ( C > 0 );

    es_triangulo = es_triangulo && ( A+B > C ); // 2 lados juntos siempre
    es_triangulo = es_triangulo && ( B+C > A ); // son ms largos que el
    es_triangulo = es_triangulo && ( C+A > B ); // otro lado

    if ( ! es_triangulo ) {
        return NO_TRIANGULO; // ==> No es tringulo
    }

    if ( (A==B) && (B==C) ) {
        return EQUILATERO; // ==> Equiltero
    }

    if ( (A==B) || (B==C) || (C==A) ) {
        return ISOSCELES; // ==> Issceles
    }
    return ESCALENO; // ==> Escaleno
}

#include "BUnit.h" // Clase de prueba
#include <iostream> // cout

/// Clase para probar el contenedor \c deque<T>
class test_Triangulo : public TestCase {
public:
    test_Triangulo() { } ///< Constructor
    /// Mtodo base que ejecuta todas las pruebas de la clase.
    bool run();
};

/// \fn void deque<T>::deque( size_type N )
/// \see test_Triangulo<T>::test_Triangulo()

/// Datos de prueba.
bool test_Triangulo::run() {
    // 1)
    assertTrue( Tipo_Triangulo(   8 , 10 , 12 ) ==  ESCALENO );

    // 2)
    assertTrue( Tipo_Triangulo(   8 , 8 , 8 ) ==  EQUILATERO );

    // 3)
    assertTrue( Tipo_Triangulo(   8 , 10 , 8 ) ==  ISOSCELES );

    // 4)
    assertTrue( Tipo_Triangulo(   10 ,  8 ,  8 ) ==  ISOSCELES );
    assertTrue( Tipo_Triangulo(    8 , 10 ,  8 ) ==  ISOSCELES );
    assertTrue( Tipo_Triangulo(    8 ,  8 , 10 ) ==  ISOSCELES );

    // 5)
    assertTrue( Tipo_Triangulo(   8 , 0 , 8 ) ==  NO_TRIANGULO );

    // 6)
    assertTrue( Tipo_Triangulo(   8 , -1 , 8 ) ==  NO_TRIANGULO );

    // 7)
    assertTrue( Tipo_Triangulo(    2 , 8 , 10 ) ==  NO_TRIANGULO );

    // 8)
    assertTrue( Tipo_Triangulo(    2 ,  8 , 10 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    2 , 10 ,  8 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    8 ,  2 , 10 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    8 , 10 ,  2 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(   10 ,  2 ,  8 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(   10 ,  8 ,  2 ) ==  NO_TRIANGULO );

    // 9)
    assertTrue( Tipo_Triangulo(    1 , 8 , 10 ) ==  NO_TRIANGULO );

    // 10)
    assertTrue( Tipo_Triangulo(    1 ,  8 , 10 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    1 , 10 ,  8 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    8 ,  1 , 10 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(    8 , 10 ,  1 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(   10 ,  1 ,  8 ) ==  NO_TRIANGULO );
    assertTrue( Tipo_Triangulo(   10 ,  8 ,  1 ) ==  NO_TRIANGULO );

    // 11)
    assertTrue( Tipo_Triangulo(   0 , 0 , 0 ) ==  NO_TRIANGULO );

    return wasSuccessful();
}

/// Programa principal que ejecuta todas las pruebas.
/// Prueba \c test_Triangulo.
int main() {
    test_Triangulo tester;
    tester.run();
    std::cout << tester.report();
    return 0;
}

// EOF: test_Triangulo.cpp
